@@ -2,13 +2,12 @@
 import unittest
 from pkg_resources import resource_listdir
 from zope.testing import doctest
-from zope.app.testing.functional import getRootFolder
-from zeam.form.composed.testing import FunctionalLayer, setUp, tearDown
+from zeam.form.composed.testing import FunctionalLayer
 
 
 def suiteFromPackage(name):
     optionflags = doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS
-    globs = {'getRootFolder': getRootFolder}
+    globs = {'getRootFolder': FunctionalLayer.getRootFolder}
     files = resource_listdir(__name__, name)
     suite = unittest.TestSuite()
     for filename in files:
@@ -21,8 +20,6 @@ def suiteFromPackage(name):
 
         dottedname = 'zeam.form.composed.ftests.%s.%s' % (name, filename[:-3])
         test = doctest.DocTestSuite(dottedname,
-                                    setUp=setUp,
-                                    tearDown=tearDown,
                                     extraglobs=globs,
                                     optionflags=optionflags)
         test.layer = FunctionalLayer
